Autonomous agents for Beam Bots, built on the Jido agent framework.
See BB.Jido.Plugin.Robot for the main integration point and the
package README for usage examples.
Autonomous agents for Beam Bots, built on the Jido agent framework.
See BB.Jido.Plugin.Robot for the main integration point and the
package README for usage examples.